@@ -1,7 +1,7 @@
 package App::fatten;
 
-our $DATE = '2015-05-15'; # DATE
-our $VERSION = '0.38'; # VERSION
+our $DATE = '2015-06-17'; # DATE
+our $VERSION = '0.39'; # VERSION
 
 use 5.010001;
 use strict;
@@ -673,73 +673,6 @@ _
             tags => ['category:stripping'],
         },
 
-        stripper => {
-            summary => 'Whether to strip included modules using Perl::Stripper',
-            'summary.alt.bool.yes' => 'Strip included modules using Perl::Stripper',
-            schema => ['bool' => default=>0],
-            tags => ['category:stripping'],
-        },
-        stripper_maintain_linum => {
-            summary => "Set maintain_linum=1 in Perl::Stripper",
-            schema => ['bool'],
-            default => 0,
-            tags => ['category:stripping'],
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-        },
-        stripper_ws => {
-            summary => "Set strip_ws=1 (strip whitespace) in Perl::Stripper",
-            'summary.alt.bool.not' => "Set strip_ws=0 (don't strip whitespace) in Perl::Stripper",
-            schema => ['bool'],
-            default => 1,
-            tags => ['category:stripping'],
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-        },
-        stripper_comment => {
-            summary => "Set strip_comment=1 (strip comments) in Perl::Stripper",
-            'summary.alt.bool.not' => "Set strip_comment=0 (don't strip comments) in Perl::Stripper",
-            schema => ['bool'],
-            default => 1,
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-            tags => ['category:stripping'],
-        },
-        stripper_pod => {
-            summary => "Set strip_pod=1 (strip POD) in Perl::Stripper",
-            'summary.alt.bool.not' => "Set strip_pod=0 (don't strip POD) in Perl::Stripper",
-            schema => ['bool'],
-            default => 1,
-            tags => ['category:stripping'],
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-        },
-        stripper_log => {
-            summary => "Set strip_log=1 (strip log statements) in Perl::Stripper",
-            'summary.alt.bool.not' => "Set strip_log=0 (don't strip log statements) in Perl::Stripper",
-            schema => ['bool'],
-            default => 0,
-            tags => ['category:stripping'],
-            description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
-        },
-        # XXX strip_log_levels
-
         debug_keep_tempdir => {
             summary => 'Keep temporary directory for debugging',
             schema => ['bool' => default=>0],
@@ -900,6 +833,116 @@ sub fatten {
     [200];
 }
 
+# IFBUILT
+sub _add_stripper_args_to_meta {
+    my $meta = shift;
+
+    # already added
+    $meta->{args}{stripper} and return [304];
+
+    $meta->{args}{stripper} = {
+        summary => 'Whether to strip included modules using Perl::Stripper',
+        'summary.alt.bool.yes' => 'Strip included modules using Perl::Stripper',
+        schema => ['bool' => default=>0],
+        tags => ['category:stripping'],
+    };
+
+    $meta->{args}{stripper_maintain_linum} = {
+        summary => "Set maintain_linum=1 in Perl::Stripper",
+        schema => ['bool'],
+        default => 0,
+        tags => ['category:stripping'],
+        description => <<'_',
+
+Only relevant when stripping using Perl::Stripper.
+
+_
+    };
+
+    $meta->{args}{stripper_ws} = {
+        summary => "Set strip_ws=1 (strip whitespace) in Perl::Stripper",
+        'summary.alt.bool.not' => "Set strip_ws=0 (don't strip whitespace) in Perl::Stripper",
+        schema => ['bool'],
+        default => 1,
+        tags => ['category:stripping'],
+        description => <<'_',
+
+Only relevant when stripping using Perl::Stripper.
+
+_
+    };
+
+    $meta->{args}{stripper_comment} = {
+        summary => "Set strip_comment=1 (strip comments) in Perl::Stripper",
+        'summary.alt.bool.not' => "Set strip_comment=0 (don't strip comments) in Perl::Stripper",
+        schema => ['bool'],
+        default => 1,
+        description => <<'_',
+
+Only relevant when stripping using Perl::Stripper.
+
+_
+        tags => ['category:stripping'],
+    };
+
+    $meta->{args}{stripper_pod} = {
+        summary => "Set strip_pod=1 (strip POD) in Perl::Stripper",
+        'summary.alt.bool.not' => "Set strip_pod=0 (don't strip POD) in Perl::Stripper",
+        schema => ['bool'],
+        default => 1,
+        tags => ['category:stripping'],
+        description => <<'_',
+
+Only relevant when stripping using Perl::Stripper.
+
+_
+    };
+
+    $meta->{args}{stripper_log} = {
+        summary => "Set strip_log=1 (strip log statements) in Perl::Stripper",
+        'summary.alt.bool.not' => "Set strip_log=0 (don't strip log statements) in Perl::Stripper",
+        schema => ['bool'],
+        default => 0,
+        tags => ['category:stripping'],
+        description => <<'_',
+
+Only relevant when stripping using Perl::Stripper.
+
+_
+    };
+
+    # XXX strip_log_levels
+
+    $meta->{args_rels} //= {};
+    my $ar = $meta->{args_rels};
+    my $prop;
+    if ($ar->{'dep_any&'}) {
+        $prop = $ar->{'dep_any&'};
+    } elsif (ref($ar->{'dep_any'}) eq 'ARRAY' && ($ar->{'dep_any.op'} // '') eq 'and') {
+        $prop = $ar->{'dep_any'};
+    } elsif (!$ar->{'dep_any'}) {
+        $ar->{'dep_any'} = [];
+        $ar->{'dep_any.op'} = 'and';
+        $prop = $ar->{'dep_any'};
+    }
+    if ($prop) {
+        push @$prop, [stripper_maintain_linum => [qw/stripper/]];
+        push @$prop, [stripper_ws             => [qw/stripper/]];
+        push @$prop, [stripper_log            => [qw/stripper/]];
+        push @$prop, [stripper_pod            => [qw/stripper/]];
+        push @$prop, [stripper_comment        => [qw/stripper/]];
+    }
+
+    [200];
+}
+
+_add_stripper_args_to_meta($SPEC{fatten});
+# END IFBUILT
+
+# IFUNBUILT
+# require PERLANCAR::AppUtil::PerlStripper; PERLANCAR::AppUtil::PerlStripper::_add_stripper_args_to_meta($SPEC{fatten});
+# END IFUNBUILT
+
 1;
 # ABSTRACT: Pack your dependencies onto your script file
 
@@ -915,7 +958,7 @@ App::fatten - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.38 of App::fatten (from Perl distribution App-fatten), released on 2015-05-15.
+This document describes version 0.39 of App::fatten (from Perl distribution App-fatten), released on 2015-06-17.
 
 =head1 SYNOPSIS
 
